Documentation
¶
Index ¶
- type Batch
- type BatchResults
- type Predicate
- func And(predicates ...Predicate) Predicate
- func Contains(field, value string) Predicate
- func EQ(field string, value interface{}) Predicate
- func GT(field string, value interface{}) Predicate
- func GTE(field string, value interface{}) Predicate
- func HasEdge(edge string) Predicate
- func HasEdgeWith(edge string, predicates ...Predicate) Predicate
- func HasPrefix(field, value string) Predicate
- func HasSuffix(field, value string) Predicate
- func In(field string, values ...interface{}) Predicate
- func IsNull(field string) Predicate
- func LT(field string, value interface{}) Predicate
- func LTE(field string, value interface{}) Predicate
- func NEQ(field string, value interface{}) Predicate
- func Not(predicate Predicate) Predicate
- func NotIn(field string, values ...interface{}) Predicate
- func NotNull(field string) Predicate
- func Or(predicates ...Predicate) Predicate
- type Query
- type Tx
- func (t *Tx) Commit(ctx context.Context) error
- func (t *Tx) Exec(ctx context.Context, sql string, args ...interface{}) (pgconn.CommandTag, error)
- func (t *Tx) Query(ctx context.Context, sql string, args ...interface{}) (pgx.Rows, error)
- func (t *Tx) QueryRow(ctx context.Context, sql string, args ...interface{}) pgx.Row
- func (t *Tx) Rollback(ctx context.Context) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Batch ¶
type Batch struct {
// contains filtered or unexported fields
}
Batch represents a batch of operations
type BatchResults ¶
type BatchResults interface {
// Exec reads the results from the next query in the batch
Exec() (pgconn.CommandTag, error)
// Query reads the results from the next query in the batch
Query() (pgx.Rows, error)
// QueryRow reads the results from the next query in the batch
QueryRow() pgx.Row
// Close closes the batch results
Close() error
}
type Predicate ¶
type Predicate interface {
String() string
Args() []interface{}
}
Predicate represents a SQL predicate
func HasEdgeWith ¶
HasEdgeWith creates a predicate to filter by relationship
Click to show internal directories.
Click to hide internal directories.